@@ -17,15 +17,21 @@
 package org.drools.workbench.screens.guided.dtable.client.editor;
 
 import java.util.Collections;
+import java.util.HashSet;
+import java.util.List;
 import java.util.Optional;
+import java.util.function.Supplier;
 
 import com.google.gwt.core.client.Scheduler;
 import com.google.gwtmockito.GwtMockitoTestRunner;
+import org.drools.workbench.models.guided.dtable.shared.model.DTCellValue52;
 import org.drools.workbench.models.guided.dtable.shared.model.GuidedDecisionTable52;
+import org.drools.workbench.screens.guided.dtable.client.editor.search.GuidedDecisionTableSearchableElement;
 import org.drools.workbench.screens.guided.dtable.client.type.GuidedDTableResourceType;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.GuidedDecisionTableView;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.DecisionTableSelectedEvent;
 import org.drools.workbench.screens.guided.dtable.model.GuidedDecisionTableEditorContent;
+import org.drools.workbench.screens.guided.dtable.shared.XLSConversionResult;
 import org.guvnor.common.services.project.categories.Decision;
 import org.guvnor.common.services.project.model.WorkspaceProject;
 import org.guvnor.common.services.shared.metadata.model.Metadata;
@@ -42,10 +48,14 @@ import org.uberfire.backend.vfs.Path;
 import org.uberfire.client.mvp.PerspectiveManager;
 import org.uberfire.ext.editor.commons.client.menu.BasicFileMenuBuilder;
 import org.uberfire.ext.editor.commons.client.menu.common.SaveAndRenameCommandBuilder;
+import org.uberfire.ext.wires.core.grids.client.model.GridData;
+import org.uberfire.ext.wires.core.grids.client.widget.grid.GridWidget;
 import org.uberfire.mvp.Command;
 import org.uberfire.mvp.PlaceRequest;
 import org.uberfire.workbench.model.menu.MenuItem;
 
+import static java.util.Arrays.asList;
+import static java.util.Collections.singletonList;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotNull;
@@ -59,17 +69,16 @@ import static org.mockito.Mockito.never;
 import static org.mockito.Mockito.reset;
 import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(GwtMockitoTestRunner.class)
 public class GuidedDecisionTableEditorPresenterTest extends BaseGuidedDecisionTablePresenterTest<GuidedDecisionTableEditorPresenter> {
 
-    private GuidedDTableResourceType resourceType = new GuidedDTableResourceType(new Decision());
-
-    @Mock
-    private SaveAndRenameCommandBuilder<GuidedDecisionTable52, Metadata> saveAndRenameCommandBuilder;
-
     @Mock
     protected AuthoringWorkbenchDocks docks;
+    private GuidedDTableResourceType resourceType = new GuidedDTableResourceType(new Decision());
+    @Mock
+    private SaveAndRenameCommandBuilder<GuidedDecisionTable52, Metadata> saveAndRenameCommandBuilder;
 
     @Override
     protected GuidedDecisionTableEditorPresenter getPresenter() {
@@ -91,10 +100,14 @@ public class GuidedDecisionTableEditorPresenterTest extends BaseGuidedDecisionTa
                                                       columnsPage,
                                                       saveAndRenameCommandBuilder,
                                                       alertsButtonMenuItemBuilder,
-                                                      downloadMenuItem) {
+                                                      downloadMenuItemBuilder,
+                                                      editorSearchIndex,
+                                                      searchBarComponent,
+                                                      searchableElementFactory) {
             {
                 workbenchContext = GuidedDecisionTableEditorPresenterTest.this.workbenchContext;
                 projectController = GuidedDecisionTableEditorPresenterTest.this.projectController;
+                promises = GuidedDecisionTableEditorPresenterTest.this.promises;
             }
 
             @Override
@@ -104,6 +117,97 @@ public class GuidedDecisionTableEditorPresenterTest extends BaseGuidedDecisionTa
         };
     }
 
+    @Test
+    public void testInit() {
+
+        final Supplier<Boolean> isDirty = () -> true;
+        final Supplier<Integer> currentHashCode = () -> 123;
+        final Command noResultsFoundCallback = () -> {/* Nothing. */};
+
+        doReturn(isDirty).when(presenter).getIsDirtySupplier();
+        doReturn(noResultsFoundCallback).when(presenter).getNoResultsFoundCallback();
+        doReturn(currentHashCode).when(presenter).getCurrentHashCodeSupplier();
+
+        presenter.init();
+
+        verify(editorSearchIndex).setNoResultsFoundCallback(noResultsFoundCallback);
+        verify(editorSearchIndex).setCurrentAssetHashcodeSupplier(currentHashCode);
+        verify(editorSearchIndex, times(2)).registerSubIndex(presenter);
+        verify(searchBarComponent, times(2)).init(editorSearchIndex);
+        verify(multiPageEditor, times(2)).addTabBarWidget(searchBarComponentWidget);
+    }
+
+    @Test
+    public void testGetCurrentHashCode() {
+
+        final GuidedDecisionTableView.Presenter activeDocument = mock(GuidedDecisionTableView.Presenter.class);
+        final Integer expectedHashcode = 123;
+
+        doReturn(activeDocument).when(presenter).getActiveDocument();
+        doReturn(expectedHashcode).when(presenter).currentHashCode(activeDocument);
+
+        final Integer actualHashcode = presenter.getCurrentHashCodeSupplier().get();
+
+        assertEquals(expectedHashcode, actualHashcode);
+    }
+
+    @Test
+    public void testGetNoResultsFoundCallback() {
+
+        final GridWidget gridWidget = mock(GridWidget.class);
+        final GridData gridData = mock(GridData.class);
+
+        when(modellerView.getGridWidgets()).thenReturn(new HashSet<>(singletonList(gridWidget)));
+        when(gridWidget.getModel()).thenReturn(gridData);
+
+        presenter.getNoResultsFoundCallback().execute();
+
+        verify(gridData).clearSelections();
+        verify(gridWidget).draw();
+    }
+
+    @Test
+    public void testGetModellerView() {
+        assertEquals(modellerView, presenter.getModellerView());
+    }
+
+    @Test
+    public void testGetSearchableElements() {
+
+        final GuidedDecisionTable52 model = mock(GuidedDecisionTable52.class);
+        final Supplier<GuidedDecisionTable52> modelSupplier = () -> model;
+        final List<DTCellValue52> row1 = asList(new DTCellValue52("cell 1"), new DTCellValue52("cell 2"));
+        final List<DTCellValue52> row2 = asList(new DTCellValue52("cell 3"), new DTCellValue52("cell 4"));
+        final List<List<DTCellValue52>> data = asList(row1, row2);
+
+        doReturn(modelSupplier).when(presenter).getContentSupplier();
+        when(model.getData()).thenReturn(data);
+
+        final List<GuidedDecisionTableSearchableElement> elements = presenter.getSearchableElements();
+
+        assertEquals(4, elements.size());
+
+        assertEquals("cell 1", elements.get(0).getValue());
+        assertEquals("cell 2", elements.get(1).getValue());
+        assertEquals("cell 3", elements.get(2).getValue());
+        assertEquals("cell 4", elements.get(3).getValue());
+
+        assertEquals(0, elements.get(0).getRow());
+        assertEquals(0, elements.get(1).getRow());
+        assertEquals(1, elements.get(2).getRow());
+        assertEquals(1, elements.get(3).getRow());
+
+        assertEquals(0, elements.get(0).getColumn());
+        assertEquals(1, elements.get(1).getColumn());
+        assertEquals(0, elements.get(2).getColumn());
+        assertEquals(1, elements.get(3).getColumn());
+
+        assertEquals(modeller, elements.get(0).getModeller());
+        assertEquals(modeller, elements.get(1).getModeller());
+        assertEquals(modeller, elements.get(2).getModeller());
+        assertEquals(modeller, elements.get(3).getModeller());
+    }
+
     @Test
     public void testSetupMenuBar() {
         verify(fileMenuBuilder,
@@ -131,11 +235,19 @@ public class GuidedDecisionTableEditorPresenterTest extends BaseGuidedDecisionTa
         verify(fileMenuBuilder).addNewTopLevelMenu(alertsButtonMenuItem);
     }
 
+    @Test
+    public void testDownloads() {
+        presenter.makeMenuBar();
+        presenter.makeMenuBar();
+
+        verify(downloadMenuItemBuilder).build(any());
+    }
+
     @Test
     public void testMakeMenuBarWithoutUpdateProjectPermission() {
         reset(fileMenuBuilder);
         doReturn(Optional.of(mock(WorkspaceProject.class))).when(workbenchContext).getActiveWorkspaceProject();
-        doReturn(false).when(projectController).canUpdateProject(any());
+        doReturn(promises.resolve(false)).when(projectController).canUpdateProject(any());
 
         presenter.makeMenuBar();
 
@@ -294,4 +406,24 @@ public class GuidedDecisionTableEditorPresenterTest extends BaseGuidedDecisionTa
         final Imports imports = dtDocument.getModel().getImports();
         verify(importsWidget).setContent(same(oracle), same(imports), eq(false));
     }
+
+    @Test
+    public void showConversionSuccess() {
+        doReturn(new XLSConversionResult()).when(dtService).convert(any());
+
+        presenter.onConvert();
+
+        verify(view).showConversionSuccess();
+        verify(view, never()).showConversionMessage(any());
+    }
+
+    @Test
+    public void showConversionMessage() {
+        doReturn(new XLSConversionResult("failed")).when(dtService).convert(any());
+
+        presenter.onConvert();
+
+        verify(view, never()).showConversionSuccess();
+        verify(view).showConversionMessage("failed");
+    }
 }
