@@ -20,14 +20,17 @@ import java.util.Set;
 
 import javax.inject.Named;
 
-import org.drools.workbench.screens.scenariosimulation.backend.server.runner.ScenarioJunitActivator;
+import org.drools.scenariosimulation.api.model.ScenarioSimulationModel;
+import org.drools.scenariosimulation.api.model.Simulation;
+import org.drools.scenariosimulation.backend.runner.ScenarioJunitActivator;
+import org.drools.scenariosimulation.backend.util.ImpossibleToFindDMNException;
 import org.drools.workbench.screens.scenariosimulation.backend.server.util.ScenarioSimulationBuilder;
-import org.drools.workbench.screens.scenariosimulation.model.ScenarioSimulationModel;
-import org.drools.workbench.screens.scenariosimulation.model.Simulation;
+import org.drools.workbench.screens.scenariosimulation.service.DMNTypeService;
 import org.guvnor.common.services.backend.config.SafeSessionInfo;
 import org.guvnor.common.services.backend.metadata.MetadataServerSideService;
 import org.guvnor.common.services.backend.util.CommentedOptionFactory;
 import org.guvnor.common.services.project.model.Dependencies;
+import org.guvnor.common.services.project.model.Dependency;
 import org.guvnor.common.services.project.model.GAV;
 import org.guvnor.common.services.project.model.POM;
 import org.guvnor.common.services.project.model.Package;
@@ -55,14 +58,19 @@ import org.uberfire.java.nio.base.options.CommentedOption;
 import org.uberfire.java.nio.file.FileAlreadyExistsException;
 import org.uberfire.java.nio.file.OpenOption;
 
+import static org.drools.scenariosimulation.api.model.ScenarioSimulationModel.Type;
+import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.anyMap;
 import static org.mockito.Matchers.anyString;
+import static org.mockito.Matchers.eq;
 import static org.mockito.Mockito.doReturn;
+import static org.mockito.Mockito.doThrow;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.never;
 import static org.mockito.Mockito.reset;
@@ -134,8 +142,20 @@ public class ScenarioSimulationServiceImplTest {
     @Mock
     private ScenarioSimulationBuilder scenarioSimulationBuilderMock;
 
+    @Mock
+    private DMNTypeService dmnTypeServiceMock;
+
     @InjectMocks
-    private ScenarioSimulationServiceImpl service = new ScenarioSimulationServiceImpl(mock(SafeSessionInfo.class));
+    private ScenarioSimulationServiceImpl service = new ScenarioSimulationServiceImpl(mock(SafeSessionInfo.class)) {
+        @Override
+        protected ScenarioSimulationModel unmarshalInternal(String content) {
+            Simulation simulation = new Simulation();
+            simulation.getSimulationDescriptor().setType(Type.DMN);
+            ScenarioSimulationModel toReturn = new ScenarioSimulationModel();
+            toReturn.setSimulation(simulation);
+            return toReturn;
+        }
+    };
 
     private Path path = PathFactory.newPath("contextPath", "file:///contextPath");
 
@@ -155,6 +175,7 @@ public class ScenarioSimulationServiceImplTest {
         when(projectPomMock.getGav()).thenReturn(gavMock);
         when(gavMock.getGroupId()).thenReturn("Test");
         when(projectPomMock.getDependencies()).thenReturn(dependenciesMock);
+        when(dependenciesMock.iterator()).thenReturn(new Dependencies().iterator());
         when(ioServiceMock.exists(any(org.uberfire.java.nio.file.Path.class))).thenReturn(false);
         when(packageMock.getPackageTestSrcPath()).thenReturn(path);
         when(scenarioSimulationBuilderMock.createSimulation(any(), any(), any())).thenReturn(new Simulation());
@@ -249,8 +270,8 @@ public class ScenarioSimulationServiceImplTest {
                                                "test.scesim",
                                                model,
                                                "Commit comment",
-                                               ScenarioSimulationModel.Type.RULE,
-                                               "default");
+                                               Type.RULE,
+                                               null);
 
         assertNotNull(returnPath);
         assertNotNull(model.getSimulation());
@@ -268,7 +289,7 @@ public class ScenarioSimulationServiceImplTest {
                                                "test.scesim",
                                                model,
                                                "Commit comment",
-                                               ScenarioSimulationModel.Type.DMN,
+                                               Type.DMN,
                                                "test");
 
         assertNotNull(returnPath);
@@ -295,12 +316,12 @@ public class ScenarioSimulationServiceImplTest {
         final Path path = mock(Path.class);
         Simulation simulation = new Simulation();
 
-        service.runScenario(path, simulation.getSimulationDescriptor(), simulation.getScenarioMap());
+        service.runScenario(path, simulation.getSimulationDescriptor(), simulation.getScenarioWithIndex());
 
         verify(scenarioRunnerServiceMock).runTest("test userMock",
                                                   path,
                                                   simulation.getSimulationDescriptor(),
-                                                  simulation.getScenarioMap());
+                                                  simulation.getScenarioWithIndex());
     }
 
     @Test
@@ -336,13 +357,14 @@ public class ScenarioSimulationServiceImplTest {
 
     @Test
     public void removeOldActivatorIfExistsTest() {
-        service.removeOldActivatorIfExists(kieModuleMock);
-        verify(ioServiceMock, times(1)).deleteIfExists(any());
+        org.uberfire.java.nio.file.Path existingActivatorPathMock = mock(org.uberfire.java.nio.file.Path.class);
+        service.removeOldActivatorIfExists(existingActivatorPathMock, kieModuleMock);
+        verify(ioServiceMock, times(2)).deleteIfExists(any());
 
         reset(ioServiceMock);
         when(kieModuleServiceMock.resolvePackages(any(KieModule.class))).thenReturn(new HashSet<>());
-        service.removeOldActivatorIfExists(kieModuleMock);
-        verify(ioServiceMock, never()).deleteIfExists(any());
+        service.removeOldActivatorIfExists(existingActivatorPathMock, kieModuleMock);
+        verify(ioServiceMock, times(1)).deleteIfExists(eq(existingActivatorPathMock));
     }
 
     @Test
@@ -365,6 +387,26 @@ public class ScenarioSimulationServiceImplTest {
                                              anyString());
     }
 
+    @Test
+    public void removeFromPomIfNecessaryTest() {
+        String groupId = "groupId";
+        String artifactId = "artifactId";
+        String version = "version";
+        GAV toRemove = new GAV(groupId, artifactId, version);
+        Dependencies dependencies = new Dependencies();
+        dependencies.add(new Dependency(toRemove));
+
+        assertTrue(service.removeFromPomIfNecessary(dependencies, toRemove));
+
+        assertFalse(service.removeFromPomIfNecessary(dependencies, toRemove));
+
+        dependencies.add(new Dependency(new GAV(groupId, artifactId, null)));
+
+        assertTrue(service.removeFromPomIfNecessary(dependencies, toRemove));
+
+        assertFalse(service.removeFromPomIfNecessary(dependencies, toRemove));
+    }
+
     @Test
     public void editPomIfNecessaryTest() {
         String groupId = "groupId";
@@ -382,4 +424,27 @@ public class ScenarioSimulationServiceImplTest {
     public void getActivatorPathTest() {
         assertTrue(service.getActivatorPath(packageMock).endsWith(ScenarioJunitActivator.ACTIVATOR_CLASS_NAME + ".java"));
     }
+
+    @Test
+    public void load() {
+        ScenarioSimulationModel model = service.load(path);
+
+        assertEquals(Type.DMN, model.getSimulation().getSimulationDescriptor().getType());
+        verify(dmnTypeServiceMock, times(1)).initializeNameAndNamespace(any(), any(), anyString());
+
+        doThrow(new ImpossibleToFindDMNException("")).when(dmnTypeServiceMock).initializeNameAndNamespace(any(), any(), anyString());
+
+        try {
+            service.load(path);
+        } catch (Exception e) {
+            fail();
+        }
+    }
+
+    // RHPAM-2089
+    @Test
+    public void checkDependencyForGTable() {
+        GAV gtableDependency = new GAV("org.drools", "drools-workbench-models-guided-dtable", null);
+        assertTrue(service.getDependencies(null).contains(gtableDependency));
+    }
 }
\ No newline at end of file
