@@ -17,6 +17,8 @@ package org.drools.workbench.screens.scenariosimulation.client.models;
 
 import java.util.AbstractMap;
 import java.util.ArrayList;
+import java.util.Arrays;
+import java.util.Collections;
 import java.util.List;
 import java.util.Map;
 import java.util.Objects;
@@ -28,7 +30,18 @@ import java.util.stream.Collectors;
 import java.util.stream.IntStream;
 
 import com.google.gwt.event.shared.EventBus;
-import org.drools.workbench.screens.scenariosimulation.client.events.ReloadRightPanelEvent;
+import org.drools.scenariosimulation.api.model.ExpressionElement;
+import org.drools.scenariosimulation.api.model.ExpressionIdentifier;
+import org.drools.scenariosimulation.api.model.FactIdentifier;
+import org.drools.scenariosimulation.api.model.FactMapping;
+import org.drools.scenariosimulation.api.model.FactMappingType;
+import org.drools.scenariosimulation.api.model.FactMappingValue;
+import org.drools.scenariosimulation.api.model.FactMappingValueStatus;
+import org.drools.scenariosimulation.api.model.Scenario;
+import org.drools.scenariosimulation.api.model.Simulation;
+import org.drools.scenariosimulation.api.model.SimulationDescriptor;
+import org.drools.scenariosimulation.api.utils.ScenarioSimulationSharedUtils;
+import org.drools.workbench.screens.scenariosimulation.client.events.ReloadTestToolsEvent;
 import org.drools.workbench.screens.scenariosimulation.client.events.ScenarioGridReloadEvent;
 import org.drools.workbench.screens.scenariosimulation.client.events.ScenarioNotificationEvent;
 import org.drools.workbench.screens.scenariosimulation.client.factories.CollectionEditorSingletonDOMElementFactory;
@@ -36,19 +49,10 @@ import org.drools.workbench.screens.scenariosimulation.client.factories.Scenario
 import org.drools.workbench.screens.scenariosimulation.client.factories.ScenarioHeaderTextBoxSingletonDOMElementFactory;
 import org.drools.workbench.screens.scenariosimulation.client.metadata.ScenarioHeaderMetaData;
 import org.drools.workbench.screens.scenariosimulation.client.resources.i18n.ScenarioSimulationEditorConstants;
+import org.drools.workbench.screens.scenariosimulation.client.utils.ScenarioSimulationUtils;
 import org.drools.workbench.screens.scenariosimulation.client.values.ScenarioGridCellValue;
 import org.drools.workbench.screens.scenariosimulation.client.widgets.ScenarioGridCell;
 import org.drools.workbench.screens.scenariosimulation.client.widgets.ScenarioGridColumn;
-import org.drools.workbench.screens.scenariosimulation.model.ExpressionElement;
-import org.drools.workbench.screens.scenariosimulation.model.ExpressionIdentifier;
-import org.drools.workbench.screens.scenariosimulation.model.FactIdentifier;
-import org.drools.workbench.screens.scenariosimulation.model.FactMapping;
-import org.drools.workbench.screens.scenariosimulation.model.FactMappingType;
-import org.drools.workbench.screens.scenariosimulation.model.FactMappingValue;
-import org.drools.workbench.screens.scenariosimulation.model.Scenario;
-import org.drools.workbench.screens.scenariosimulation.model.Simulation;
-import org.drools.workbench.screens.scenariosimulation.model.SimulationDescriptor;
-import org.drools.workbench.screens.scenariosimulation.utils.ScenarioSimulationSharedUtils;
 import org.uberfire.ext.wires.core.grids.client.model.GridCell;
 import org.uberfire.ext.wires.core.grids.client.model.GridCellValue;
 import org.uberfire.ext.wires.core.grids.client.model.GridColumn;
@@ -56,6 +60,8 @@ import org.uberfire.ext.wires.core.grids.client.model.GridRow;
 import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridData;
 import org.uberfire.workbench.events.NotificationEvent;
 
+import static org.drools.workbench.screens.scenariosimulation.client.utils.ScenarioSimulationUtils.getPropertyNameElementsWithoutAlias;
+
 public class ScenarioGridModel extends BaseGridData {
 
     public static final int HEADER_ROW_COUNT = 3;
@@ -215,6 +221,21 @@ public class ScenarioGridModel extends BaseGridData {
         insertRowGridOnly(newRowIndex, row, toDuplicate);
     }
 
+    /**
+     * This method <i>duplicates</i> the row values at the source column index from both the grid <b>and</b> the underlying model
+     * and inserts at the target column index
+     * @param originalColumnIndex
+     * @param newColumnIndex
+     */
+    public void duplicateColumnValues(int originalColumnIndex, int newColumnIndex) {
+        checkSimulation();
+        List<GridCellValue<?>> originalValues = new ArrayList<>();
+        IntStream.range(0, getRowCount())
+                .forEach(rowIndex -> originalValues.add(getCell(rowIndex, originalColumnIndex).getValue()));
+        IntStream.range(0, getRowCount())
+                .forEach(rowIndex -> setCellValue(rowIndex, newColumnIndex, originalValues.get(rowIndex)));
+    }
+
     /**
      * This method <i>insert</i> a new column to the grid <b>without</b> modify underlying model
      * @param index
@@ -254,43 +275,53 @@ public class ScenarioGridModel extends BaseGridData {
      */
     public void updateColumnInstance(int columnIndex, final GridColumn<?> column) {
         checkSimulation();
-        deleteColumn(columnIndex);
-        String group = ((ScenarioGridColumn) column).getInformationHeaderMetaData().getColumnGroup();
-        String columnId = ((ScenarioGridColumn) column).getInformationHeaderMetaData().getColumnId();
-        ExpressionIdentifier ei = ExpressionIdentifier.create(columnId, FactMappingType.valueOf(group));
-        commonAddColumn(columnIndex, column, ei);
+        replaceColumn(columnIndex, column);
     }
 
     /**
      * This method update the type mapped inside a give column and updates the underlying model
      * @param columnIndex
      * @param column
-     * @param value
+     * @param propertyNameElements
      * @param lastLevelClassName
      * @param keepData
      */
-    public void updateColumnProperty(int columnIndex, final GridColumn<?> column, String value, String lastLevelClassName, boolean keepData) {
+    public void updateColumnProperty(int columnIndex, final GridColumn<?> column, List<String> propertyNameElements, String lastLevelClassName, boolean keepData) {
         checkSimulation();
         List<GridCellValue<?>> originalValues = new ArrayList<>();
         if (keepData) {
             IntStream.range(0, getRowCount())
                     .forEach(rowIndex -> originalValues.add(getCell(rowIndex, columnIndex).getValue()));
         }
-        deleteColumn(columnIndex);
-        String group = ((ScenarioGridColumn) column).getInformationHeaderMetaData().getColumnGroup();
-        String columnId = ((ScenarioGridColumn) column).getInformationHeaderMetaData().getColumnId();
-        String[] elements = value.split("\\.");
-        ExpressionIdentifier ei = ExpressionIdentifier.create(columnId, FactMappingType.valueOf(group));
-        commonAddColumn(columnIndex, column, ei);
+        replaceColumn(columnIndex, column);
         final FactMapping factMappingByIndex = simulation.getSimulationDescriptor().getFactMappingByIndex(columnIndex);
-        IntStream.range(0, elements.length)
-                .forEach(stepIndex -> factMappingByIndex.addExpressionElement(elements[stepIndex], lastLevelClassName));
+        List<String> propertyNameElementsClone = getPropertyNameElementsWithoutAlias(propertyNameElements, factMappingByIndex.getFactIdentifier());
+        // This is because the value starts with the alias of the fact; i.e. it may be Book.name but also Bookkk.name,
+        // while the first element of ExpressionElements is always the class name
+        IntStream.range(0, propertyNameElementsClone.size())
+                .forEach(stepIndex -> factMappingByIndex.addExpressionElement(propertyNameElementsClone.get(stepIndex), lastLevelClassName));
         if (keepData) {
             IntStream.range(0, getRowCount())
                     .forEach(rowIndex -> setCellValue(rowIndex, columnIndex, originalValues.get(rowIndex)));
         }
     }
 
+    /**
+     * This method replace a column at columnIndex position with a new column. It also save and restore width of the columns
+     * @param columnIndex
+     * @param column
+     */
+    protected void replaceColumn(int columnIndex, GridColumn<?> column) {
+        List<Double> widthsToRestore = getColumns().stream().map(GridColumn::getWidth).collect(Collectors.toList());
+        deleteColumn(columnIndex);
+        String group = ((ScenarioGridColumn) column).getInformationHeaderMetaData().getColumnGroup();
+        String columnId = ((ScenarioGridColumn) column).getInformationHeaderMetaData().getColumnId();
+        ExpressionIdentifier ei = ExpressionIdentifier.create(columnId, FactMappingType.valueOf(group));
+        commonAddColumn(columnIndex, column, ei);
+        IntStream.range(0, widthsToRestore.size())
+                .forEach(index -> getColumns().get(index).setWidth(widthsToRestore.get(index)));
+    }
+
     /**
      * This method <i>set</i> a cell value to the grid <b>without</b> modify underlying model
      * @param rowIndex
@@ -436,18 +467,31 @@ public class ScenarioGridModel extends BaseGridData {
                 .count();
     }
 
-    public void updateHeader(int columnIndex, int headerRowIndex, String value) {
+    /**
+     * Returns the count of instantiated facts given a classname.
+     * @param className
+     * @return
+     */
+    public int getInstancesCount(String className) {
+        return simulation.getSimulationDescriptor().getUnmodifiableFactMappings()
+                .stream()
+                .filter(factMapping -> factMapping.getFactIdentifier().getClassName().equals(className))
+                .collect(Collectors.groupingBy(FactMapping::getFactAlias))
+                .size();
+    }
+
+    public void updateHeader(int columnIndex, int headerRowIndex, String headerCellValue) {
         final ScenarioHeaderMetaData editedMetadata = (ScenarioHeaderMetaData) getColumns().get(columnIndex).getHeaderMetaData().get(headerRowIndex);
         // do not update if old and new value are the same
-        if (Objects.equals(editedMetadata.getTitle(), value)) {
+        if (Objects.equals(editedMetadata.getTitle(), headerCellValue)) {
             return;
         }
         SimulationDescriptor simulationDescriptor = simulation.getSimulationDescriptor();
         FactMapping factMappingToEdit = simulationDescriptor.getFactMappingByIndex(columnIndex);
         ScenarioHeaderMetaData.MetadataType metadataType = editedMetadata.getMetadataType();
-        IntStream.range(0, getColumnCount()).forEach(index -> updateFactMapping(simulationDescriptor, factMappingToEdit, index, value, metadataType));
-        if (editedMetadata.isInstanceHeader()) {
-            eventBus.fireEvent(new ReloadRightPanelEvent(false));
+        IntStream.range(0, getColumnCount()).forEach(index -> updateFactMapping(simulationDescriptor, factMappingToEdit, index, headerCellValue, metadataType));
+        if (editedMetadata.getMetadataType().equals(ScenarioHeaderMetaData.MetadataType.INSTANCE)) {
+            eventBus.fireEvent(new ReloadTestToolsEvent(false));
         }
     }
 
@@ -532,51 +576,66 @@ public class ScenarioGridModel extends BaseGridData {
     /**
      * Returns <code>true</code> if property mapped to the selected column is already assigned to
      * another column of the same <b>instance</b>
-     * @param propertyName
+     * @param propertyNameElements
      * @return
      */
-    public boolean isAlreadyAssignedProperty(String propertyName) {
-        return selectedColumn == null || isAlreadyAssignedProperty(getColumns().indexOf(selectedColumn), propertyName);
+    public boolean isAlreadyAssignedProperty(List<String> propertyNameElements) {
+        boolean toReturn = selectedColumn == null;
+        if (!toReturn) {
+            try {
+                checkAlreadyAssignedProperty(getColumns().indexOf(selectedColumn), propertyNameElements);
+            } catch (Exception e) {
+                toReturn = true;
+            }
+        }
+        return toReturn;
     }
 
     /**
-     * Returns <code>true</code> if property mapped to the column at given index is already assigned to
+     * Check if property mapped to the column at given index is already assigned to
      * another column of the same <b>instance</b>
      * @param columnIndex
-     * @param propertyName
-     * @return
+     * @param propertyNameElements
+     * @throws Exception if the given <code>propertyNameElements</code> are already mapped to a column of the same <b>instance</b>
      */
-    public boolean isAlreadyAssignedProperty(int columnIndex, String propertyName) {
+    public void checkAlreadyAssignedProperty(int columnIndex, List<String> propertyNameElements) throws Exception {
         Range instanceLimits = getInstanceLimits(columnIndex);
         SimulationDescriptor simulationDescriptor = simulation.getSimulationDescriptor();
-        return IntStream.range(instanceLimits.getMinRowIndex(), instanceLimits.getMaxRowIndex() + 1)
+        FactIdentifier factIdentifier = simulationDescriptor.getFactMappingByIndex(columnIndex).getFactIdentifier();
+        List<String> propertyNameElementsClone = new ArrayList<>(); // We have to keep the original List unmodified
+        propertyNameElementsClone.add(factIdentifier.getClassNameWithoutPackage());
+        propertyNameElementsClone.addAll(propertyNameElements.subList(1, propertyNameElements.size()));
+        if (IntStream.range(instanceLimits.getMinRowIndex(), instanceLimits.getMaxRowIndex() + 1)
                 .filter(index -> index != columnIndex)
                 .mapToObj(simulationDescriptor::getFactMappingByIndex)
                 .anyMatch(factMapping -> {
-                    String columnProperty = factMapping.getExpressionElements()
+                    List<String> factMappingPropertyNameElements = factMapping.getExpressionElements()
                             .stream()
-                            .map(expressionElement -> expressionElement.getStep())
-                            .collect(Collectors.joining("."));
-                    return Objects.equals(columnProperty, propertyName);
-                });
+                            .map(ExpressionElement::getStep)
+                            .collect(Collectors.toList());
+                    return Objects.equals(factMappingPropertyNameElements, propertyNameElementsClone);
+                })) {
+            throw new Exception(String.join(".", propertyNameElements) + " has already been used in the current instance.");
+        }
     }
 
     /**
      * Returns <code>true</code> if property mapped to the selected column is the same as the provided one
-     * @param propertyName
+     * @param propertyNameElements
      * @return
      */
-    public boolean isSameSelectedColumnProperty(String propertyName) {
-        return selectedColumn == null || isSameSelectedColumnProperty(getColumns().indexOf(selectedColumn), propertyName);
+    public boolean isSameSelectedColumnProperty(List<String> propertyNameElements) {
+        return selectedColumn == null || isSameSelectedColumnProperty(getColumns().indexOf(selectedColumn), propertyNameElements);
     }
 
     /**
      * Returns <code>true</code> if property mapped to the column at given index is the same as the provided one
      * @param columnIndex
-     * @param propertyName
+     * @param propertyNameElements
      * @return
      */
-    public boolean isSameSelectedColumnProperty(int columnIndex, String propertyName) {
+    public boolean isSameSelectedColumnProperty(int columnIndex, List<String> propertyNameElements) {
+        String propertyName = String.join(".", propertyNameElements);
         SimulationDescriptor simulationDescriptor = simulation.getSimulationDescriptor();
         final FactMapping factMappingByIndex = simulationDescriptor.getFactMappingByIndex(columnIndex);
         return factMappingByIndex.getExpressionAlias().equals(propertyName);
@@ -604,48 +663,85 @@ public class ScenarioGridModel extends BaseGridData {
     }
 
     /**
-     * Returns <code>true</code> if given <b>headerName</b> is the same as the <b>Fact</b> mapped to the
+     * Returns <code>true</code> if no column is selected <b>OR</b> if type of the <b>INSTANCE</b> mapped to the selected column is the same as the provided one
+     * @param className
+     * @return
+     */
+    public boolean isSameInstanceType(String className) {
+        return selectedColumn == null || isSameInstanceType(getColumns().indexOf(selectedColumn), className);
+    }
+
+     /**
+     * Check if given <b>headerName</b> is the same as the <b>Fact</b> mapped to the
      * column at given index
      * @param columnIndex
      * @param headerName
-     * @return
+     * @throws Exception if the given <b>headerName</b> is not the name of the class mapped to the given column
      */
-    public boolean isSameInstanceHeader(int columnIndex, String headerName) {
-        SimulationDescriptor simulationDescriptor = simulation.getSimulationDescriptor();
-        final FactIdentifier factIdentifierByIndex = simulationDescriptor.getFactMappingByIndex(columnIndex).getFactIdentifier();
-        String columnClassName = factIdentifierByIndex.getClassName();
-        if (columnClassName.contains(".")) {
-            columnClassName = columnClassName.substring(columnClassName.lastIndexOf(".") + 1);
+    public void checkSameInstanceHeader(int columnIndex, String headerName) throws Exception {
+        if (!isSameInstanceType(columnIndex, headerName)) {
+            throw new Exception(headerName + " is not the class of the current column.");
         }
-        return Objects.equals(columnClassName, headerName);
+
     }
 
     /**
-     * Returns <code>true</code> if given <b>headerName</b> is the same as the <b>element steps</b> mapped to any other column of the same group
+     * Returns <code>true</code> if type of the <b>INSTANCE</b> mapped to the column at given index is the same as the provided one
      * @param columnIndex
      * @param headerName
      * @return
      */
-    public boolean isSamePropertyHeader(int columnIndex, String headerName) {
+    public boolean isSameInstanceType(int columnIndex, String headerName) {
         SimulationDescriptor simulationDescriptor = simulation.getSimulationDescriptor();
-        final FactMapping factMapping = simulationDescriptor.getFactMappingByIndex(columnIndex);
-        String columnPropertyName = factMapping.getExpressionElements().stream().map(ExpressionElement::getStep).collect(Collectors.joining("."));
-        if (columnPropertyName.contains(".")) {
-            columnPropertyName = columnPropertyName.substring(columnPropertyName.indexOf(".") + 1);
-        }
-        return Objects.equals(columnPropertyName, headerName);
+        final FactIdentifier factIdentifierByIndex = simulationDescriptor.getFactMappingByIndex(columnIndex).getFactIdentifier();
+        return Objects.equals(factIdentifierByIndex.getClassNameWithoutPackage(), headerName);
     }
 
+    /**
+     * Check if given <b>headerName</b> is the same as the <b>element steps</b> mapped to the given column
+     * @param columnIndex
+     * @param propertyNameElements
+     * @throws Exception if the given <b>propertyNameElements</b> (corrected for the class name) represents the <b>element steps</b> of the given column
+     */
+    public void checkSamePropertyHeader(int columnIndex, List<String> propertyNameElements) throws Exception {
+        SimulationDescriptor simulationDescriptor = simulation.getSimulationDescriptor();
+        final FactMapping factMapping = simulationDescriptor.getFactMappingByIndex(columnIndex);
+        List<String> columnPropertyName = factMapping.getExpressionElementsWithoutClass().stream().map(ExpressionElement::getStep).collect(Collectors.toList());
+        if (!Objects.equals(columnPropertyName, propertyNameElements)) {
+            throw new Exception(String.join(".", propertyNameElements) + " is not the same property of the current column.");
+        }
+    }
+
+    /**
+     * It resets the <code>FactMappingValue</code> status for all CELLS
+     */
     public void resetErrors() {
         IntStream.range(0, getRowCount()).forEach(this::resetErrors);
     }
 
+    /**
+     * It resets the <code>FactMappingValue</code> status for a specific ROW
+     * @param rowIndex
+     */
     public void resetErrors(int rowIndex) {
         Scenario scenarioByIndex = simulation.getScenarioByIndex(rowIndex);
         scenarioByIndex.resetErrors();
         refreshErrors();
     }
 
+    /**
+     * It resets the <code>FactMappingValue</code> status for a specific CELL
+     * @param rowIndex
+     * @param columnIndex
+     */
+    public void resetError(int rowIndex, int columnIndex) {
+        Scenario scenarioByIndex = simulation.getScenarioByIndex(rowIndex);
+        FactMapping factMapping = simulation.getSimulationDescriptor().getFactMappingByIndex(columnIndex);
+        Optional<FactMappingValue> factMappingValue = scenarioByIndex.getFactMappingValue(factMapping);
+        factMappingValue.ifPresent(fmv -> fmv.resetStatus());
+        refreshErrors();
+    }
+
     public void refreshErrors() {
         IntStream.range(0, getRowCount()).forEach(this::refreshErrorsRow);
     }
@@ -666,13 +762,42 @@ public class ScenarioGridModel extends BaseGridData {
         this.simpleJavaTypeInstancesName = simpleJavaTypeInstancesName;
     }
 
-    public boolean validateInstanceHeaderUpdate(String value, int columnIndex, boolean isADataType) {
-        boolean isSameInstanceHeader = isSameInstanceHeader(columnIndex, value);
-        return (isADataType && isSameInstanceHeader && isUniqueInstanceHeaderTitle(value, columnIndex)) || (!isADataType && isUniqueInstanceHeaderTitle(value, columnIndex));
+    /**
+     * Check validity of given <b>instanceHeaderCellValue</b>
+     * @param instanceHeaderCellValue
+     * @param columnIndex
+     * @param isADataType
+     * @throws Exception with message specific to failed check
+     */
+    public void validateInstanceHeaderUpdate(String instanceHeaderCellValue, int columnIndex, boolean isADataType) throws Exception {
+        if (isADataType) {
+            checkSameInstanceHeader(columnIndex, instanceHeaderCellValue);
+            checkValidAndUniqueInstanceHeaderTitle(instanceHeaderCellValue, columnIndex);
+        } else {
+            checkValidAndUniqueInstanceHeaderTitle(instanceHeaderCellValue, columnIndex);
+        }
     }
 
-    public boolean validatePropertyHeaderUpdate(String value, int columnIndex, boolean isPropertyType) {
-        return (isPropertyType && isSamePropertyHeader(columnIndex, value) && isUniquePropertyHeaderTitle(value, columnIndex)) || (!isPropertyType && !isAlreadyAssignedProperty(columnIndex, value) && isUniquePropertyHeaderTitle(value, columnIndex));
+    /**
+     * Check validity of given <b>propertyHeaderCellValue</b>
+     * @param propertyHeaderCellValue
+     * @param columnIndex
+     * @param isPropertyType
+     * @throws Exception with message specific to failed check
+     */
+    public void validatePropertyHeaderUpdate(String propertyHeaderCellValue, int columnIndex, boolean isPropertyType) throws Exception {
+        List<String> propertyNameElements = Collections.unmodifiableList(Arrays.asList(propertyHeaderCellValue.split("\\.")));
+        if (isPropertyType) {
+            checkSamePropertyHeader(columnIndex, propertyNameElements);
+            checkUniquePropertyHeaderTitle(propertyHeaderCellValue, columnIndex);
+        } else {
+            checkAlreadyAssignedProperty(columnIndex, propertyNameElements);
+            checkValidAndUniquePropertyHeaderTitle(propertyHeaderCellValue, columnIndex);
+        }
+    }
+
+    public boolean isSimpleType(String factClassName) {
+        return simpleJavaTypeInstancesName.contains(factClassName);
     }
 
     /**
@@ -763,7 +888,10 @@ public class ScenarioGridModel extends BaseGridData {
         IntStream.range(1, getColumnCount()).forEach(columnIndex -> {
             final FactMapping factMappingByIndex = simulationDescriptor.getFactMappingByIndex(columnIndex);
             scenario.addMappingValue(factMappingByIndex.getFactIdentifier(), factMappingByIndex.getExpressionIdentifier(), null);
-            String placeHolder = ((ScenarioGridColumn) columns.get(columnIndex)).isPropertyAssigned() ? ScenarioSimulationEditorConstants.INSTANCE.insertValue() : ScenarioSimulationEditorConstants.INSTANCE.defineValidType();
+            String editableCellPlaceholder = ScenarioSimulationUtils.getPlaceholder(factMappingByIndex.getClassName());
+            String placeHolder = ((ScenarioGridColumn) columns.get(columnIndex)).isPropertyAssigned() ?
+                    editableCellPlaceholder :
+                    ScenarioSimulationEditorConstants.INSTANCE.defineValidType();
             setCell(rowIndex, columnIndex, () -> {
                 ScenarioGridCell newCell = new ScenarioGridCell(new ScenarioGridCellValue(null, placeHolder));
                 if (ScenarioSimulationSharedUtils.isCollection((factMappingByIndex.getClassName()))) {
@@ -796,39 +924,62 @@ public class ScenarioGridModel extends BaseGridData {
 
     /**
      * Verify the given value is not already used as instance header name <b>between different groups</b>
-     * @param value
+     * @param instanceHeaderCellValue
      * @param columnIndex
-     * @return
+     * @throws Exception if the given <b>instanceHeaderCellValue</b> contains a <i>dot</i> <b>OR</b> it has already been used
+     * inside the <b>group (GIVEN/EXPECT)</b> of the given column
      */
-    protected boolean isUniqueInstanceHeaderTitle(String value, int columnIndex) {
+    protected void checkValidAndUniqueInstanceHeaderTitle(String instanceHeaderCellValue, int columnIndex) throws Exception {
+        if (instanceHeaderCellValue.contains(".")) {
+            throw new Exception("An instance alias cannot contain periods!");
+        }
         Range instanceLimits = getInstanceLimits(columnIndex);
         SimulationDescriptor simulationDescriptor = simulation.getSimulationDescriptor();
         FactIdentifier factIdentifier = simulationDescriptor.getFactMappingByIndex(columnIndex).getFactIdentifier();
-        return IntStream.range(0, getColumnCount())
+        if (IntStream.range(0, getColumnCount())
                 .filter(index -> index < instanceLimits.getMinRowIndex() || index > instanceLimits.getMaxRowIndex())
                 .filter(index -> !Objects.equals(factIdentifier, simulationDescriptor.getFactMappingByIndex(index).getFactIdentifier()))
                 .mapToObj(index -> (ScenarioGridColumn) getColumns().get(index))
                 .filter(elem -> elem.getInformationHeaderMetaData() != null)
                 .map(ScenarioGridColumn::getInformationHeaderMetaData)
-                .noneMatch(elem -> Objects.equals(elem.getTitle(), value));
+                .anyMatch(elem -> Objects.equals(elem.getTitle(), instanceHeaderCellValue))) {
+            throw new Exception(instanceHeaderCellValue + " has already been used inside the current group");
+        }
     }
 
     /**
-     * Verify the given value is not already used as property header name <b>inside the same group</b>
-     * @param value
+     * Verify if the given value is not already used as property header name <b>inside the same instance</b>
+     * @param propertyHeaderCellValue
      * @param columnIndex
-     * @return
+     * @throws Exception if the given <b>propertyHeaderCellValue</b> contains a <i>dot</i> <b>OR</b> it has already been used
+     * inside the <b>instance</b> of the given column
      */
-    protected boolean isUniquePropertyHeaderTitle(String value, int columnIndex) {
+    protected void checkValidAndUniquePropertyHeaderTitle(String propertyHeaderCellValue, int columnIndex) throws Exception {
+        if (propertyHeaderCellValue.contains(".")) {
+            throw new Exception("A property alias cannot contain periods!");
+        }
+        checkUniquePropertyHeaderTitle(propertyHeaderCellValue, columnIndex);
+    }
+
+    /**
+     * Verify if the given value is not already used as property header name <b>inside the same instance</b>
+     * @param propertyHeaderCellValue
+     * @param columnIndex
+     * @throws Exception if the given <b>propertyHeaderCellValue</b> has already been used
+     * inside the <b>instance</b> of the given column
+     */
+    protected void checkUniquePropertyHeaderTitle(String propertyHeaderCellValue, int columnIndex) throws Exception {
         SimulationDescriptor simulationDescriptor = simulation.getSimulationDescriptor();
         FactIdentifier factIdentifier = simulationDescriptor.getFactMappingByIndex(columnIndex).getFactIdentifier();
-        return IntStream.range(0, getColumnCount())
+        if (IntStream.range(0, getColumnCount())
                 .filter(index -> index != columnIndex)
                 .filter(index -> Objects.equals(factIdentifier, simulationDescriptor.getFactMappingByIndex(index).getFactIdentifier()))
                 .mapToObj(index -> (ScenarioGridColumn) getColumns().get(index))
                 .filter(elem -> elem.getPropertyHeaderMetaData() != null)
                 .map(ScenarioGridColumn::getPropertyHeaderMetaData)
-                .noneMatch(elem -> Objects.equals(elem.getTitle(), value));
+                .anyMatch(elem -> Objects.equals(elem.getTitle(), propertyHeaderCellValue))) {
+            throw new Exception(propertyHeaderCellValue + " has already been used inside the current instance");
+        }
     }
 
     protected boolean isNewInstanceName(String value) {
@@ -856,7 +1007,7 @@ public class ScenarioGridModel extends BaseGridData {
             final FactMapping factMappingByIndex = simulationDescriptor.getFactMappingByIndex(columnIndex);
             Optional<FactMappingValue> factMappingValue = scenarioByIndex.getFactMappingValue(factMappingByIndex.getFactIdentifier(), factMappingByIndex.getExpressionIdentifier());
             if (factMappingValue.isPresent()) {
-                cell.setErrorMode(factMappingValue.get().isError());
+                cell.setErrorMode(FactMappingValueStatus.SUCCESS != factMappingValue.get().getStatus());
             } else {
                 cell.setErrorMode(false);
             }
